AcxTextType enum
Values
- h4 → const AcxTextType
- h5 → const AcxTextType
- h6 → const AcxTextType
- sh1 → const AcxTextType
- sh2 → const AcxTextType
- caption → const AcxTextType
- overline → const AcxTextType
- d1 → const AcxTextType
- d2 → const AcxTextType
- d3 → const AcxTextType
- h1 → const AcxTextType
- h2 → const AcxTextType
- h3 → const AcxTextType
- t1 → const AcxTextType
- t2 → const AcxTextType
- t3 → const AcxTextType
- l1 → const AcxTextType
- l2 → const AcxTextType
- l3 → const AcxTextType
- b1 → const AcxTextType
- b2 → const AcxTextType
- b3 → const AcxTextType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AcxTextType> - A constant List of the values in this enum, in order of their declaration.